
%--------------------------------------------------------------------------
%   This function creates a GUI for doing animations. 
%--------------------------------------------------------------------------
%   Callback Usage:
%   x = AnimationGUI( action, a, b, c  ) 
% 
%   Command Line Usage:
%   AnimationGUI( 'initialize', scData, tgtData, time, options ) 
%--------------------------------------------------------------------------
% 
%   ------ 
%   Inputs 
%   ------ 
%   action          (1,:)   Action to take. Use 'initialize' to create GUI.
%   scData           (.)    Spacecraft data strcture. Fields: 
%                             .r    (3,n)    Position
%                             .t    (1,n)    Time
%                             .c    (3,1)    Constant color, OR:
%                             .c    (3,n)    Time-varying color
%                             .name (:)      Name for labeling
%                             .axis (3,n)    Axis vector for pointing cone
%                             .angle(1,n)    Field of view of cone
%   tgtData          (.)    Target data strcture.     Fields: r, t, c
%   time            (1,N)   Time vector with N points.
%   options          (.)    Data structure with display options.
%     .axisType     (1,:)   Specifies how to draw axis background 
%                           and labels. Choices: 'Hills', 'LVLH', 'Earth', 
%                           'EarthHR' or any other planet name. If a planet 
%                           is chosen it will be drawn in the background. 
%                           In this case it is best to supply planet-fixed 
%                           coordinates so that the trajectory is drawn 
%                           properly with respect to the planet image.
%     .docked       (1,1)   Flag. Specify whether the axes are docked with
%                           the UI controls (1) or in a separated window (0)
%     .view         (1,:)   String. '2D' or '3D'. If 2D, 3rd row is set to 0.
%     .date         (1,1)   Initial Julian date, for lighting of planet axis type 
%                           only. In this case the time units must be seconds
%                           for accurate lighting effects.
% 
%   ------- 
%   Outputs 
%   ------- 
%   x                (:)    Outputs only supplied when called as a callback
%                           function from the GUI.
% 
%--------------------------------------------------------------------------